@@ -1,7 +1,6 @@
-use std::collections::HashMap;
-use pyo3::prelude::*;
 use pyo3::exceptions::PyLookupError;
-
+use pyo3::prelude::*;
+use std::collections::HashMap;
 
 #[pyclass(name = "Router")]
 struct Router {
@@ -26,7 +25,9 @@ impl Router {
     }
 
     pub fn insert<'py>(&mut self, route: String, value: String) {
-        self.inner.insert(route, value).expect("TODO: panic message");
+        self.inner
+            .insert(route, value)
+            .expect("TODO: panic message");
     }
 
     pub fn at<'py>(&mut self, path: &str) -> PyResult<MatchResult> {
@@ -34,20 +35,23 @@ impl Router {
         if matched.is_ok() {
             let unwrapped = matched.unwrap();
             let mut d = HashMap::new();
-            for (k, v) in unwrapped.params.iter()  {
+            for (k, v) in unwrapped.params.iter() {
                 d.insert(k.to_string(), v.to_string());
             }
-            Ok(MatchResult{route: unwrapped.value.to_string(), params: d})
+            Ok(MatchResult {
+                route: unwrapped.value.to_string(),
+                params: d,
+            })
         } else {
             Err(PyErr::new::<PyLookupError, _>("No route found"))
         }
     }
 }
 
-#[pymodule(name="matchit")]
+#[pymodule(name = "matchit", gil_used = false)]
 mod python_matchit {
-    #[pymodule_export]
-    use super::Router;
     #[pymodule_export]
     use super::MatchResult;
+    #[pymodule_export]
+    use super::Router;
 }
